@@ -48,7 +48,7 @@ aqiColors <- function(
   pollutant = c("PM2.5", "AQI", "CO", "NO", "OZONE", "PM10", "SO2"),
   palette = c("EPA", "subdued", "deuteranopia"),
   na.color = NA,
-  NAAQS = c("PM2.5", "PM2.5_2024")
+  NAAQS = c("PM2.5_2024", "PM2.5")
 ) {
 
   # ----- Validate parameters --------------------------------------------------
