@@ -75,7 +75,7 @@ monitor_dailyThreshold <- function(
   na.rm = TRUE,
   minHours = 18,
   dayBoundary = c("clock", "LST"),
-  NAAQS = c("PM2.5", "PM2.5_2024")
+  NAAQS = c("PM2.5_2024", "PM2.5")
 ) {
 
   # ----- Validate parameters --------------------------------------------------
